==> xixiBlog-0.11.zip: xixiBlog/comment_delete.php <==
<?php
/**
@brief ꤵ줿 id  Ȥޤ
@author minahito
@version $Id$
*/

$xoopsOption['nocommon']=true;
include_once "../../mainfile.php";
require_once XOOPS_ROOT_PATH."/modules/exFrame/frameloader.php";
require_once "./class/global.php";

// 桼¦ǻѤ Confirm ̤ǰʥݡͥȤѤ
require_once "exComponent/confirm/TypicalConfirm.php";
// ɤɤ߹
require_once "exComponent/confirm/processor/TypicalConfirmDeleteProcessor.php";
// ŪʥǥȤꤢѤ
require_once "exComponent/render/ConfirmModelRender.php";

require_once "include/OnetimeTicket.php";

// Session 
require_once XOOPS_ROOT_PATH."/include/common.php";
require_once XOOPS_ROOT_PATH."/header.php";

// ꥯȤϰʤΤǡActionForm ѤˤξǽԤ
$id = isset($_REQUEST['cid']) ? intval($_REQUEST['cid']) : 0;
$handler=&xixiBlog::getHandler('comment');
$obj=&$handler->get($cid);
if(!is_object($obj)) 
	redirect_header("./index.php",1,"̵ CID Ǥ");

// ¤γǧΤ˥֥Ф
$b_handler=&xixiBlog::getHandler("blog");
$blog=&$b_handler->get($obj->getVar("id"));
if(!is_object($blog)) 
	redirect_header("./index.php",1,"̵ CID Ǥ");

// 
$uid = is_object($xoopsUser) ? $xoopsUser->uid() : 0;
$perm = exPerm::Guard('delete_comment_otherblog') ? true : false;
if(exPerm::Guard('delete_comment_mine') && $obj->getVar('uid')==$uid)
	$perm=true;
elseif(exPerm::Guard('delete_comment_myblog') && $blog->getVar('uid')==$uid)
	$perm=true;

if(!$perm)
	redirect_header('index.php',1,_MD_XIXIBLOG_MESSAGE_NO_PERM);

// 
$path="detail.php?id=".$obj->getVar('id');
$forwards=array(new exSuccessForwardConfig(EXFORWARD_REDIRECT,$path,"Ԥޤ"),
		new exFailForwardConfig(EXFORWARD_REDIRECT,$path,"˼Ԥޤ"));

$compo = new exTypicalConfirmComponent(new TypicalConfirmObjectDeleteProcessor(),
				new exConfirmComponentModelRender(),
				'comment_delete',new exObjectConfirmTicketForm(),$forwards);

switch($compo->init($obj,$handler)) {
	case COMPONENT_INIT_FAIL:
		die;

	case COMPONENT_INIT_SUCCESS:
		$compo->display();
		break;
}

require_once XOOPS_ROOT_PATH."/footer.php";
?>

==> xixiBlog-0.13.zip: xixiBlog/comment_delete.php <==
<?php
/**
@brief ꤵ줿 id  Ȥޤ
@author minahito
@version $Id$
*/

$xoopsOption['nocommon']=true;
include_once "../../mainfile.php";
require_once XOOPS_ROOT_PATH."/modules/exFrame/frameloader.php";
require_once "./class/global.php";

// 桼¦ǻѤ Confirm ̤ǰʥݡͥȤѤ
require_once "exComponent/confirm/TypicalConfirm.php";
// ɤɤ߹
require_once "exComponent/confirm/processor/TypicalConfirmDeleteProcessor.php";
// ŪʥǥȤꤢѤ
require_once "exComponent/render/ConfirmModelRender.php";

require_once "include/OnetimeTicket.php";

// Session 
require_once XOOPS_ROOT_PATH."/include/common.php";
require_once XOOPS_ROOT_PATH."/header.php";

// ꥯȤϰʤΤǡActionForm ѤˤξǽԤ
$cid = isset($_REQUEST['cid']) ? intval($_REQUEST['cid']) : 0;
$handler=&xixiBlog::getHandler('comment');
$obj=&$handler->get($cid);
if(!is_object($obj)) 
	redirect_header("./index.php",1,"̵ CID Ǥ");

// ¤γǧΤ˥֥Ф
$b_handler=&xixiBlog::getHandler("blog");
$blog=&$b_handler->get($obj->getVar("id"));
if(!is_object($blog)) 
	redirect_header("./index.php",1,"̵ CID Ǥ");

// 
$uid = is_object($xoopsUser) ? $xoopsUser->uid() : 0;
$perm = exPerm::Guard('delete_comment_otherblog') ? true : false;
if(exPerm::Guard('delete_comment_mine') && $obj->getVar('uid')==$uid)
	$perm=true;
elseif(exPerm::Guard('delete_comment_myblog') && $blog->getVar('uid')==$uid)
	$perm=true;

if(!$perm)
	redirect_header('index.php',1,_MD_XIXIBLOG_MESSAGE_NO_PERM);

// 
$path="detail.php?id=".$obj->getVar('id');
$forwards=array(new exSuccessForwardConfig(EXFORWARD_REDIRECT,$path,"Ԥޤ"),
		new exFailForwardConfig(EXFORWARD_REDIRECT,$path,"˼Ԥޤ"));

$compo = new exTypicalConfirmComponent(new TypicalConfirmObjectDeleteProcessor(),
				new exConfirmComponentModelRender(),
				'comment_delete',new exObjectConfirmTicketForm(),$forwards);

switch($compo->init($obj,$handler)) {
	case COMPONENT_INIT_FAIL:
		die;

	case COMPONENT_INIT_SUCCESS:
		$compo->display();
		break;
}

require_once XOOPS_ROOT_PATH."/footer.php";
?>
